@@ -1,4 +1,4 @@
-/* X11::GUITest ($Id: main.h,v 1.2 2011/05/01 10:50:59 ctrondlp Exp $)
+/* X11::GUITest ($Id: main.h 203 2011-05-15 02:03:11Z ctrondlp $)
  *  
  * Copyright (c) 2003-2011 Dennis K. Paulsen, All Rights Reserved.
  * Email: ctrondlp@cpan.org
@@ -22,22 +22,26 @@
 
 #define APP_NAME "x11guirecord"
 
-#define MIN_DELAY_MS 50
+#define DEFAULT_WAIT_SECS 1
+#define DEFAULT_DELAY_MS 50
+#define MIN_DELAY_MS 0
+#define MAX_DELAY_MS 1000
 #define MAX_KEY_NAME 35
-#define MIN_KEYDELAY_MS 1000
+#define MAX_KEYDELAY_BEFOREFLUSH_MS 1000
 #define MOUSE_DBLCLICK_THRESHOLD 300
 #define MAX_MBUTTON_NAME 25
 #define MAX_KEY_BUFFER 128
 #define KEY_BUFFER_THRESHOLD 60
+#define MIN_WAIT_SECONDS 1 
 #define MAX_WAIT_SECONDS 240 
 #define MIN_GRANULARITY 1
 #define MAX_GRANULARITY 10
 
-BOOL GetMouseButtonFromIndex(int index, char *button);
-void HandleDelay(unsigned long delay);
-void HandleKeyBuffer(BOOL force);
-void ProcessEvent(struct record_event ev);
-BOOL IsMouseMoveTooGranular(struct record_event ev);
+static BOOL GetMouseButtonFromIndex(int index, char *button);
+static void HandleDelay(unsigned long delay);
+static void HandleKeyBuffer(BOOL forceKeyFlush);
+static void ProcessEvent(struct record_event ev);
+static BOOL IsMouseMoveTooGranular(struct record_event ev);
 
 
 #endif /* #ifndef MAIN_H */
